Enum influxdb2_structmap::value::Value [−][src]
pub enum Value {
Unknown,
String(String),
Double(f64),
Bool(bool),
Long(i64),
UnsignedLong(u64),
Duration(Duration),
Base64Binary(Vec<u8>),
TimeRFC(DateTime<FixedOffset>),
}Expand description
Represents primitive types that are supported for conversion into a BTreeMap that can support
heterogeneous values. Inspired by serde_json::Values.
Variants
Tuple Fields of String
0: StringTuple Fields of Double
0: f64Tuple Fields of Bool
0: boolTuple Fields of Long
0: i64Tuple Fields of UnsignedLong
0: u64Tuple Fields of Duration
0: DurationTuple Fields of TimeRFC
0: DateTime<FixedOffset>Implementations
Given a genericized input type, encapsulate it as a Value that can be used in a map container type when converting to and from a struct.